from setuptools import setup

setup(
    name="pyramage",
    version="1.0.0",
    description="Python random image generator built using perlin noise algorithm",
    keywords="Python Random Image Generator Perlin Noise Algorithm",
    url="https://github.com/sreedevk/pyramage.git",
    author="Sreedev Kodichat",
    author_email="sreedevpadmakumar@gmail.com",
    license="MIT",
    packages=["pyramage"],
    install_requires=["matplotlib", "numpy"],
    zip_safe=False
)
